diff --git a/interface/resources/images/about-opus.png b/interface/resources/images/about-opus.png
new file mode 100644
index 0000000000..57924b070f
Binary files /dev/null and b/interface/resources/images/about-opus.png differ
diff --git a/interface/resources/images/about-projectathena.png b/interface/resources/images/about-projectathena.png
new file mode 100644
index 0000000000..ae2d2bcd06
Binary files /dev/null and b/interface/resources/images/about-projectathena.png differ
diff --git a/interface/resources/qml/hifi/dialogs/TabletAboutDialog.qml b/interface/resources/qml/hifi/dialogs/TabletAboutDialog.qml
index 91e40aa608..821879139b 100644
--- a/interface/resources/qml/hifi/dialogs/TabletAboutDialog.qml
+++ b/interface/resources/qml/hifi/dialogs/TabletAboutDialog.qml
@@ -25,7 +25,7 @@ Rectangle {
Image {
sourceSize.width: 295
sourceSize.height: 75
- source: "../../../images/about-highfidelity.png"
+ source: "../../../images/about-projectathena.png"
}
Item { height: 30; width: 1 }
Column {
@@ -56,9 +56,9 @@ Rectangle {
text: "Project Athena Github."
size: 20
onLinkActivated: {
- HiFiAbout.openUrl("https:/github.com/kasenvr/hifi-community");
+ HiFiAbout.openUrl("https:/github.com/kasenvr/project-athena");
}
-
+
}
Item { height: 40; width: 1 }
Row {
@@ -93,17 +93,31 @@ Rectangle {
anchors.verticalCenter: parent.verticalCenter
}
}
+ Row {
+ spacing: 5
+ Image {
+ sourceSize.width: 34
+ sourceSize.height: 25
+ source: "../../../images/about-opus.png"
+ MouseArea {
+ anchors.fill: parent
+ onClicked: {
+ HiFiAbout.openUrl("http://opus-codec.org/");
+ }
+ }
+ }
+ RalewayRegular {
+ color: "white"
+ text: "Built using the Opus codec."
+ size: 12
+ anchors.verticalCenter: parent.verticalCenter
+ }
+ }
Item { height: 20; width: 1 }
RalewayRegular {
- textFormat: Text.StyledText
- linkColor: "#00B4EF"
color: "white"
- property string link: "https://eos.io/"
- text: "Blockchain technology from EOS."
+ text: "© 2019 - 2020 Project Athena Contributors"
size: 14
- onLinkActivated: {
- HiFiAbout.openUrl(link);
- }
}
RalewayRegular {
color: "white"
diff --git a/interface/src/Menu.cpp b/interface/src/Menu.cpp
index 1be67ef188..e4ea9d8c45 100644
--- a/interface/src/Menu.cpp
+++ b/interface/src/Menu.cpp
@@ -768,8 +768,8 @@ Menu::Menu() {
// Help/Application menu ----------------------------------
MenuWrapper * helpMenu = addMenu("Help");
- // Help > About High Fidelity
- action = addActionToQMenuAndActionHash(helpMenu, "About High Fidelity");
+ // Help > About Project Athena
+ action = addActionToQMenuAndActionHash(helpMenu, "About Project Athena");
connect(action, &QAction::triggered, [] {
qApp->showDialog(QString("hifi/dialogs/AboutDialog.qml"),
QString("hifi/dialogs/TabletAboutDialog.qml"), "AboutDialog");
@@ -807,7 +807,7 @@ Menu::Menu() {
// Help > Report a Bug!
action = addActionToQMenuAndActionHash(helpMenu, "Report a Bug!");
connect(action, &QAction::triggered, qApp, [] {
- QDesktopServices::openUrl(QUrl("https://github.com/kasenvr/hifi-community/issues"));
+ QDesktopServices::openUrl(QUrl("https://github.com/kasenvr/project-athena/issues"));
});
}